@@ -3,7 +3,7 @@ package Moose::Meta::Attribute::Native::Trait;
 use Moose::Role;
 use Moose::Util::TypeConstraints;
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -34,9 +34,6 @@ has 'method_constructors' => (
     },
 );
 
-has '+default'         => ( required => 1 );
-has '+type_constraint' => ( required => 1 );
-
 # methods called prior to instantiation
 
 before '_process_options' => sub {
@@ -138,13 +135,15 @@ __END__
 
 =head1 NAME
 
-Moose::Meta::Attribute::Native::Trait - base role for helpers
+Moose::Meta::Attribute::Native::Trait - Base role for helpers
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
+
+=head1 SEE ALSO
+
+Documentation for Moose native traits starts at L<Moose::Meta::Attribute Native>
 
 =head1 AUTHORS
 
