@@ -11,7 +11,7 @@ use List::Util qw( first );
 use List::MoreUtils qw( any all uniq first_index );
 use Scalar::Util 'weaken', 'blessed';
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -68,11 +68,36 @@ sub initialize {
             );
 }
 
+sub reinitialize {
+    my $self = shift;
+    my $pkg  = shift;
+
+    my $meta = blessed $pkg ? $pkg : Class::MOP::class_of($pkg);
+
+    my %existing_classes;
+    if ($meta) {
+        %existing_classes = map { $_ => $meta->$_() } qw(
+            attribute_metaclass
+            method_metaclass
+            wrapped_method_metaclass
+            instance_metaclass
+            constructor_class
+            destructor_class
+            error_class
+        );
+    }
+
+    return $self->SUPER::reinitialize(
+        $pkg,
+        %existing_classes,
+        @_,
+    );
+}
+
 sub _immutable_options {
     my ( $self, @args ) = @_;
 
     $self->SUPER::_immutable_options(
-        allow_mutable_ancestors => 0,
         inline_destructor => 1,
 
         # Moose always does this when an attribute is created
@@ -141,36 +166,6 @@ sub add_role {
     push @{$self->roles} => $role;
 }
 
-sub make_immutable {
-    my $self = shift;
-    my %args = @_;
-
-    # we do this for metaclasses way too often to do this check for them
-    if ( !$args{allow_mutable_ancestors}
-      && !$self->name->isa('Class::MOP::Object') ) {
-        my @superclasses = grep { $_ ne 'Moose::Object' && $_ ne $self->name }
-            $self->linearized_isa;
-
-        for my $superclass (@superclasses) {
-            my $meta = Class::MOP::class_of($superclass);
-
-            next unless $meta && $meta->isa('Moose::Meta::Class');
-            next unless $meta->is_mutable;
-            # This can happen when a base class role is applied via
-            # Moose::Util::MetaRole::apply_base_class_roles. The parent is an
-            # anon class and is still mutable, but that's okay.
-            next if $meta->is_anon_class;
-
-            Carp::cluck( "Calling make_immutable on "
-                    . $self->name
-                    . ", which has a mutable ancestor ($superclass)" );
-            last;
-        }
-    }
-
-    $self->SUPER::make_immutable(@_);
-}
-
 sub role_applications {
     my ($self) = @_;
 
@@ -327,29 +322,8 @@ sub _find_next_method_by_name_which_is_not_overridden {
 sub _fix_metaclass_incompatibility {
     my ($self, @superclasses) = @_;
 
-    foreach my $super (@superclasses) {
-        my $meta = Class::MOP::Class->initialize($super);
-
-        my @all_supers = $meta->linearized_isa;
-        shift @all_supers;
-
-        my @super_metas_to_fix = ($meta);
-
-        # We need to check & fix the immediate superclass. If its @ISA
-        # contains a class without a metaclass instance, followed by a
-        # class _with_ a metaclass instance, init a metaclass instance
-        # for classes without one and fix compat up to and including
-        # the class which was already initialized.
-        my $idx = first_index { Class::MOP::class_of($_) } @all_supers;
-
-        push @super_metas_to_fix,
-            map { Class::MOP::Class->initialize($_) } @all_supers[ 0 .. $idx ]
-            if $idx >= 0;
-
-        foreach my $super_meta (@super_metas_to_fix) {
-            $self->_fix_one_incompatible_metaclass($super_meta);
-        }
-    }
+    $self->_fix_one_incompatible_metaclass($_)
+        for map { Moose::Meta::Class->initialize($_) } @superclasses;
 }
 
 sub _fix_one_incompatible_metaclass {
@@ -734,10 +708,6 @@ enables inlining the destructor.
 Also, since Moose always inlines attributes, it sets the
 C<inline_accessors> option to false.
 
-It also accepts the additional C<allow_mutable_ancestors> option, to
-silence the warning you get when trying to make a class with mutable
-ancestors immutable.
-
 =item B<< $metaclass->new_object(%params) >>
 
 This overrides the parent's method in order to add support for
@@ -811,9 +781,7 @@ Throws the error created by C<create_error> using C<raise_error>
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
@@ -821,7 +789,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+Copyright 2006-2010 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
