@@ -6,7 +6,7 @@ use warnings;
 
 use Scalar::Util 'blessed', 'weaken', 'looks_like_number', 'refaddr';
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use base 'Moose::Meta::Method',
@@ -43,11 +43,6 @@ sub new {
     return $self;
 }
 
-# This is here so can_be_inlined can be inherited by MooseX modules.
-sub _expected_constructor_class {
-    return 'Moose::Object';
-}
-
 ## method
 
 sub _initialize_body {
@@ -61,6 +56,7 @@ sub _initialize_body {
     # the author, after all, nothing is free)
     my $source = 'sub {';
     $source .= "\n" . 'my $_instance = shift;';
+
     $source .= "\n" . 'my $class = Scalar::Util::blessed($_instance) || $_instance;';
 
     $source .= "\n" . 'return $class->Moose::Object::new(@_)';
@@ -376,13 +372,17 @@ L<Class::MOP::Class::Constructor> documentation as well.
 C<Moose::Meta::Method::Constructor> is a subclass of
 L<Moose::Meta::Method> I<and> L<Class::MOP::Method::Constructor>.
 
+=head1 BUGS
+
+See L<Moose/BUGS> for details on reporting bugs.
+
 =head1 AUTHORS
 
 Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+Copyright 2006-2010 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
