@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken';
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -104,17 +104,29 @@ sub _initialize_body {
                 object      => $instance
             );
         }
-        my @args = (@{ $self->curried_arguments }, @_);
-        $proxy->$method_to_call(@args);
+        unshift @_, @{ $self->curried_arguments };
+        $proxy->$method_to_call(@_);
     };
 }
 
 sub _get_delegate_accessor {
     my $self = shift;
+    my $attr = $self->associated_attribute;
 
-    my $accessor = $self->associated_attribute->get_read_method_ref;
+    # NOTE:
+    # always use a named method when
+    # possible, if you use the method
+    # ref and there are modifiers on
+    # the accessors then it will not
+    # pick up the modifiers too. Only
+    # the named method will assure that
+    # we also have any modifiers run.
+    # - SL
+    my $accessor = $attr->has_read_method
+        ? $attr->get_read_method
+        : $attr->get_read_method_ref;
 
-    $accessor = $accessor->body if blessed $accessor;
+    $accessor = $accessor->body if Scalar::Util::blessed $accessor;
 
     return $accessor;
 }
@@ -178,9 +190,7 @@ constructor.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
