@@ -7,19 +7,20 @@ use metaclass;
 
 use Scalar::Util 'blessed';
 use Carp         'confess';
-use Sub::Name    'subname';
 use Devel::GlobalDestruction 'in_global_destruction';
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Moose::Meta::Class;
+use Moose::Meta::Role::Attribute;
 use Moose::Meta::Role::Method;
 use Moose::Meta::Role::Method::Required;
 use Moose::Meta::Role::Method::Conflicting;
+use Moose::Util qw( ensure_all_roles );
 
-use base 'Class::MOP::Module';
+use base 'Class::MOP::Module', 'Class::MOP::Mixin::HasAttributes';
 
 ## ------------------------------------------------------------------
 ## NOTE:
@@ -71,16 +72,6 @@ foreach my $action (
             existence  => 'requires_method',
         }
     },
-    {
-        name        => 'attribute_map',
-        attr_reader => 'get_attribute_map',
-        methods     => {
-            get       => 'get_attribute',
-            get_keys  => 'get_attribute_list',
-            existence => 'has_attribute',
-            remove    => 'remove_attribute',
-        }
-    }
 ) {
 
     my $attr_reader = $action->{attr_reader};
@@ -160,23 +151,60 @@ $META->add_attribute(
     default => 'Moose::Meta::Role::Application::ToInstance',
 );
 
-## some things don't always fit, so they go here ...
+# More or less copied from Moose::Meta::Class
+sub initialize {
+    my $class = shift;
+    my $pkg   = shift;
+    return Class::MOP::get_metaclass_by_name($pkg)
+        || $class->SUPER::initialize(
+        $pkg,
+        'attribute_metaclass' => 'Moose::Meta::Role::Attribute',
+        @_
+        );
+}
+
+sub reinitialize {
+    my $self = shift;
+    my $pkg  = shift;
+
+    my $meta = blessed $pkg ? $pkg : Class::MOP::class_of($pkg);
+
+    my %existing_classes;
+    if ($meta) {
+        %existing_classes = map { $_ => $meta->$_() } qw(
+            attribute_metaclass
+            method_metaclass
+            wrapped_method_metaclass
+            required_method_metaclass
+            conflicting_method_metaclass
+            application_to_class_class
+            application_to_role_class
+            application_to_instance_class
+        );
+    }
+
+    return $self->SUPER::reinitialize(
+        $pkg,
+        %existing_classes,
+        @_,
+    );
+}
 
 sub add_attribute {
     my $self = shift;
-    my $name = shift;
-    unless ( defined $name ) {
-        require Moose;
-        Moose->throw_error("You must provide a name for the attribute");
+
+    if (blessed $_[0] && ! $_[0]->isa('Moose::Meta::Role::Attribute') ) {
+        my $class = ref $_[0];
+        Moose->throw_error( "Cannot add a $class as an attribute to a role" );
     }
-    my $attr_desc;
-    if (scalar @_ == 1 && ref($_[0]) eq 'HASH') {
-        $attr_desc = $_[0];
-    }
-    else {
-        $attr_desc = { @_ };
-    }
-    $self->get_attribute_map->{$name} = $attr_desc;
+
+    return $self->SUPER::add_attribute(@_);
+}
+
+sub _attach_attribute {
+    my ( $self, $attribute ) = @_;
+
+    $attribute->attach_to_role($self);
 }
 
 sub add_required_methods {
@@ -355,129 +383,8 @@ sub does_role {
     return 0;
 }
 
-## ------------------------------------------------------------------
-## methods
-
-sub get_method_map {
-    my $self = shift;
-
-    my $current = Class::MOP::check_package_cache_flag($self->name);
-
-    if (defined $self->{'_package_cache_flag'} && $self->{'_package_cache_flag'} == $current) {
-        return $self->{'methods'} ||= {};
-    }
-
-    $self->{_package_cache_flag} = $current;
-
-    my $map  = $self->{'methods'} ||= {};
-
-    my $role_name        = $self->name;
-    my $method_metaclass = $self->method_metaclass;
-
-    my $all_code = $self->get_all_package_symbols('CODE');
-
-    foreach my $symbol (keys %{ $all_code }) {
-        my $code = $all_code->{$symbol};
-
-        next if exists  $map->{$symbol} &&
-                defined $map->{$symbol} &&
-                        $map->{$symbol}->body == $code;
-
-        my ($pkg, $name) = Class::MOP::get_code_info($code);
-        my $meta = Class::MOP::class_of($pkg);
-
-        if ($meta && $meta->isa('Moose::Meta::Role')) {
-            my $role = $meta->name;
-            next unless $self->does_role($role);
-        }
-        else {
-            # NOTE:
-            # in 5.10 constant.pm the constants show up
-            # as being in the right package, but in pre-5.10
-            # they show up as constant::__ANON__ so we
-            # make an exception here to be sure that things
-            # work as expected in both.
-            # - SL
-            unless ($pkg eq 'constant' && $name eq '__ANON__') {
-                next if ($pkg  || '') ne $role_name ||
-                        (($name || '') ne '__ANON__' && ($pkg  || '') ne $role_name);
-            }
-        }
-
-        $map->{$symbol} = $method_metaclass->wrap(
-            $code,
-            package_name => $role_name,
-            name         => $name
-        );
-    }
-
-    return $map;
-}
-
-sub get_method {
-    my ($self, $name) = @_;
-    $self->get_method_map->{$name};
-}
-
-sub has_method {
-    my ($self, $name) = @_;
-    exists $self->get_method_map->{$name} ? 1 : 0
-}
-
-# FIXME this is copy-pasted from Class::MOP::Class
-# refactor to inherit from some common base
-sub wrap_method_body {
-    my ( $self, %args ) = @_;
-
-    ('CODE' eq ref $args{body})
-        || Moose->throw_error("Your code block must be a CODE reference");
-
-    $self->method_metaclass->wrap(
-        package_name => $self->name,
-        %args,
-    );
-}
-
-sub add_method {
-    my ($self, $method_name, $method) = @_;
-    (defined $method_name && $method_name)
-    || Moose->throw_error("You must define a method name");
-
-    my $body;
-    if (blessed($method)) {
-        $body = $method->body;
-        if ($method->package_name ne $self->name) {
-            $method = $method->clone(
-                package_name => $self->name,
-                name         => $method_name
-            ) if $method->can('clone');
-        }
-    }
-    else {
-        $body = $method;
-        $method = $self->wrap_method_body( body => $body, name => $method_name );
-    }
-
-    $method->attach_to_class($self);
-
-    $self->get_method_map->{$method_name} = $method;
-
-    my $full_method_name = ($self->name . '::' . $method_name);
-    $self->add_package_symbol(
-        { sigil => '&', type => 'CODE', name => $method_name },
-        subname($full_method_name => $body)
-    );
-
-    $self->update_package_cache_flag; # still valid, since we just added the method to the map, and if it was invalid before that then get_method_map updated it
-}
-
 sub find_method_by_name { (shift)->get_method(@_) }
 
-sub get_method_list {
-    my $self = shift;
-    grep { !/^meta$/ } keys %{$self->get_method_map};
-}
-
 sub alias_method {
     Carp::cluck("The alias_method method is deprecated. Use add_method instead.\n");
 
@@ -511,10 +418,11 @@ sub apply {
     return $application_class->new(@args)->apply($self, $other);
 }
 
+sub composition_class_roles { }
+
 sub combine {
     my ($class, @role_specs) = @_;
 
-    require Moose::Meta::Role::Application::RoleSummation;
     require Moose::Meta::Role::Composite;
 
     my (@roles, %role_params);
@@ -530,11 +438,7 @@ sub combine {
     }
 
     my $c = Moose::Meta::Role::Composite->new(roles => \@roles);
-    Moose::Meta::Role::Application::RoleSummation->new(
-        role_params => \%role_params
-    )->apply($c);
-
-    return $c;
+    return $c->apply_params(\%role_params);
 }
 
 sub _role_for_combination {
@@ -576,7 +480,8 @@ sub create {
     if (exists $options{attributes}) {
         foreach my $attribute_name (keys %{$options{attributes}}) {
             my $attr = $options{attributes}->{$attribute_name};
-            $meta->add_attribute($attribute_name => $attr);
+            $meta->add_attribute(
+                $attribute_name => blessed $attr ? $attr : %{$attr} );
         }
     }
 
@@ -685,20 +590,6 @@ sub create {
 #     }
 # );
 #
-# has 'attribute_map' => (
-#     metaclass => 'Hash',
-#     reader    => 'get_attribute_map',
-#     isa       => 'HashRef[Str]',
-#     provides => {
-#         # 'set'  => 'add_attribute' # has some special crap in it
-#         'get'    => 'get_attribute',
-#         'keys'   => 'get_attribute_list',
-#         'exists' => 'has_attribute',
-#         # Not exactly delete, cause it sets multiple
-#         'delete' => 'remove_attribute',
-#     }
-# );
-#
 # has 'required_methods' => (
 #     metaclass => 'Hash',
 #     reader    => 'get_required_methods_map',
@@ -818,6 +709,14 @@ and C<-alias> keys to control how methods are composed from the role.
 The return value is a new L<Moose::Meta::Role::Composite> that
 represents the combined roles.
 
+=item B<< $metarole->composition_class_roles >>
+
+When combining multiple roles using C<combine>, this method is used to obtain a
+list of role names to be applied to the L<Moose::Meta::Role::Composite>
+instance returned by C<combine>. The default implementation returns an empty
+list. Extensions that need to hook into role combination may wrap this method
+to return additional role names.
+
 =item B<< Moose::Meta::Role->create($name, %options) >>
 
 This method is identical to the L<Moose::Meta::Class> C<create>
@@ -913,12 +812,10 @@ L<Moose::Meta::Role::Method>.
 
 =item B<< $metarole->get_method_list >>
 
-=item B<< $metarole->get_method_map >>
-
 =item B<< $metarole->find_method_by_name($name) >>
 
 These methods are all identical to the methods of the same name in
-L<Class::MOP::Class>
+L<Class::MOP::Package>
 
 =back
 
@@ -941,8 +838,6 @@ This is quite likely to change in the future.
 
 =item B<< $metarole->has_attribute($attribute_name) >>
 
-=item B<< $metarole->get_attribute_map >>
-
 =item B<< $metarole->get_attribute_list >>
 
 =item B<< $metarole->add_attribute($name, %options) >>
@@ -1037,9 +932,7 @@ This will return a L<Class::MOP::Class> instance for this class.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
@@ -1047,7 +940,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+Copyright 2006-2010 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
