@@ -6,7 +6,7 @@ use metaclass;
 
 use Scalar::Util    'blessed';
 
-our $VERSION   = '0.89_02';
+our $VERSION   = '0.93_01';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -63,8 +63,7 @@ sub apply_attributes {
         }
         else {
             $role2->add_attribute(
-                $attribute_name,
-                $role1->get_attribute($attribute_name)
+                $role1->get_attribute($attribute_name)->clone
             );
         }
     }
@@ -73,6 +72,7 @@ sub apply_attributes {
 sub apply_methods {
     my ($self, $role1, $role2) = @_;
     foreach my $method_name ($role1->get_method_list) {
+        next if $method_name eq 'meta';
 
         unless ( $self->is_method_excluded($method_name) ) {
             if (   $role2->has_method($method_name)
@@ -208,9 +208,7 @@ Moose::Meta::Role::Application::ToRole - Compose a role into another role
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+See L<Moose/BUGS> for details on reporting bugs.
 
 =head1 AUTHOR
 
@@ -218,7 +216,7 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2009 by Infinity Interactive, Inc.
+Copyright 2006-2010 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
